==> legendary-0.14.0.tgz: package/doc/toc.js <==
window.files = [
{
  "path": "README.md.html",
  "originalName": "README.md",
  "originalPath": "README.md",
  "name": "README.md.html",
  "title": "Legendary",
  "toc": [
    {
      "level": 1,
      "slug": "legendary",
      "title": "Legendary"
    },
    {
      "level": 2,
      "slug": "installation",
      "title": "Installation"
    },
    {
      "level": 2,
      "slug": "usage",
      "title": "Usage"
    },
    {
      "level": 2,
      "slug": "theme-song",
      "title": "Theme song"
    }
  ]
},
{
  "path": "lib/legendary.js.html",
  "originalName": "legendary.js",
  "originalPath": "lib/legendary.js",
  "name": "legendary.js.html",
  "lang": "javascript",
  "title": "Legendary",
  "toc": [
    {
      "level": 1,
      "slug": "legendary",
      "title": "Legendary"
    },
    {
      "level": 2,
      "slug": "promise",
      "title": "Promise"
    },
    {
      "level": 2,
      "slug": "series",
      "title": "Series"
    },
    {
      "level": 2,
      "slug": "cancellationerror",
      "title": "CancellationError"
    },
    {
      "level": 2,
      "slug": "timeouterror",
      "title": "TimeoutError"
    },
    {
      "level": 2,
      "slug": "timed",
      "title": "timed"
    },
    {
      "level": 2,
      "slug": "concurrent",
      "title": "concurrent"
    },
    {
      "level": 2,
      "slug": "fn",
      "title": "fn"
    },
    {
      "level": 2,
      "slug": "unhandledrejection-reason-",
      "title": "unhandledRejection(reason)"
    }
  ]
},
{
  "path": "lib/promises.js.html",
  "originalName": "promises.js",
  "originalPath": "lib/promises.js",
  "name": "promises.js.html",
  "lang": "javascript",
  "title": "Promise",
  "toc": [
    {
      "level": 1,
      "slug": "promise",
      "title": "Promise"
    },
    {
      "level": 2,
      "slug": "promise-isinstance-x-",
      "title": "Promise.isInstance(x)"
    },
    {
      "level": 2,
      "slug": "promise-from-value-",
      "title": "Promise.from(value)"
    },
    {
      "level": 2,
      "slug": "promise-rejected-reason-",
      "title": "Promise.rejected(reason)"
    },
    {
      "level": 2,
      "slug": "promise-races",
      "title": "Promise Races"
    },
    {
      "level": 3,
      "slug": "promise-all-input-",
      "title": "Promise.all(input)"
    },
    {
      "level": 3,
      "slug": "promise-any-input-",
      "title": "Promise.any(input)"
    },
    {
      "level": 3,
      "slug": "promise-some-input-winsrequired-",
      "title": "Promise.some(input, winsRequired)"
    },
    {
      "level": 3,
      "slug": "promise-join-input-",
      "title": "Promise.join(...input)"
    },
    {
      "level": 2,
      "slug": "promise-then-onfulfilled-onrejected-",
      "title": "Promise#then(onFulfilled, onRejected)"
    },
    {
      "level": 2,
      "slug": "promise-inspectstate-",
      "title": "Promise#inspectState()"
    },
    {
      "level": 2,
      "slug": "promise-cancel-",
      "title": "Promise#cancel()"
    },
    {
      "level": 2,
      "slug": "promise-fork-",
      "title": "Promise#fork()"
    },
    {
      "level": 2,
      "slug": "promise-uncancellable-",
      "title": "Promise#uncancellable()"
    },
    {
      "level": 2,
      "slug": "promise-to-constructor-",
      "title": "Promise#to(constructor)"
    },
    {
      "level": 2,
      "slug": "promise-trace-label-meta-",
      "title": "Promise#trace(label, meta)"
    },
    {
      "level": 2,
      "slug": "promise-tracefulfilled-label-meta-",
      "title": "Promise#traceFulfilled(label, meta)"
    },
    {
      "level": 2,
      "slug": "promise-tracerejected-label-meta-",
      "title": "Promise#traceRejected(label, meta)"
    },
    {
      "level": 2,
      "slug": "promise-yield-value-",
      "title": "Promise#yield(value)"
    },
    {
      "level": 2,
      "slug": "promise-yieldreason-reason-",
      "title": "Promise#yieldReason(reason)"
    },
    {
      "level": 2,
      "slug": "promise-otherwise-onrejected-",
      "title": "Promise#otherwise(onRejected)"
    },
    {
      "level": 2,
      "slug": "promise-ensure-onfulfilledorrejected-",
      "title": "Promise#ensure(onFulfilledOrRejected)"
    },
    {
      "level": 2,
      "slug": "promise-tap-onfulfilledsideeffect-onrejectedsideeffect-",
      "title": "Promise#tap(onFulfilledSideEffect, onRejectedSideEffect)"
    },
    {
      "level": 2,
      "slug": "promise-spread-variadiconfulfilled-",
      "title": "Promise#spread(variadicOnFulfilled)"
    },
    {
      "level": 2,
      "slug": "promise-nodeify-callback-",
      "title": "Promise#nodeify(callback)"
    },
    {
      "level": 2,
      "slug": "promise-cancelafter-milliseconds-",
      "title": "Promise#cancelAfter(milliseconds)"
    },
    {
      "level": 2,
      "slug": "promise-alsocancels-other-",
      "title": "Promise#alsoCancels(other)"
    },
    {
      "level": 2,
      "slug": "promise-send-methodname-args-",
      "title": "Promise#send(methodName, ...args)"
    },
    {
      "level": 2,
      "slug": "promise-prop-name-",
      "title": "Promise#prop(name)"
    }
  ]
},
{
  "path": "lib/series.js.html",
  "originalName": "series.js",
  "originalPath": "lib/series.js",
  "name": "series.js.html",
  "lang": "javascript",
  "title": "Series",
  "toc": [
    {
      "level": 1,
      "slug": "series",
      "title": "Series"
    },
    {
      "level": 2,
      "slug": "series-map-iterator-",
      "title": "Series#map(iterator)"
    },
    {
      "level": 2,
      "slug": "series-mapparallel-maxconcurrent-iterator-",
      "title": "Series#mapParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-each-iterator-",
      "title": "Series#each(iterator)"
    },
    {
      "level": 2,
      "slug": "series-eachparallel-maxconcurrent-iterator-",
      "title": "Series#eachParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-filter-iterator-",
      "title": "Series#filter(iterator)"
    },
    {
      "level": 2,
      "slug": "series-filterparallel-maxconcurrent-iterator-",
      "title": "Series#filterParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-filterout-iterator-",
      "title": "Series#filterOut(iterator)"
    },
    {
      "level": 2,
      "slug": "series-filteroutparallel-maxconcurrent-iterator-",
      "title": "Series#filterOutParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-concat-iterator-",
      "title": "Series#concat(iterator)"
    },
    {
      "level": 2,
      "slug": "series-concatparallel-maxconcurrent-iterator-",
      "title": "Series#concatParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-foldl-initialvalue-iterator-",
      "title": "Series#foldl(initialValue, iterator)"
    },
    {
      "level": 2,
      "slug": "series-foldr-initialvalue-iterator-",
      "title": "Series#foldr(initialValue, iterator)"
    },
    {
      "level": 2,
      "slug": "series-detect-iterator-",
      "title": "Series#detect(iterator)"
    },
    {
      "level": 2,
      "slug": "series-detectparallel-maxconcurrent-iterator-",
      "title": "Series#detectParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-some-iterator-",
      "title": "Series#some(iterator)"
    },
    {
      "level": 2,
      "slug": "series-someparallel-maxconcurrent-iterator-",
      "title": "Series#someParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-every-iterator-",
      "title": "Series#every(iterator)"
    },
    {
      "level": 2,
      "slug": "series-everyparallel-maxconcurrent-iterator-",
      "title": "Series#everyParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-sortby-iterator-",
      "title": "Series#sortBy(iterator)"
    },
    {
      "level": 2,
      "slug": "series-sortbyparallel-maxconcurrent-iterator-",
      "title": "Series#sortByParallel(maxConcurrent, iterator)"
    }
  ]
},
{
  "path": "lib/CancellationError.js.html",
  "originalName": "CancellationError.js",
  "originalPath": "lib/CancellationError.js",
  "name": "CancellationError.js.html",
  "lang": "javascript",
  "title": "CancellationError",
  "toc": [
    {
      "level": 1,
      "slug": "cancellationerror",
      "title": "CancellationError"
    }
  ]
},
{
  "path": "lib/TimeoutError.js.html",
  "originalName": "TimeoutError.js",
  "originalPath": "lib/TimeoutError.js",
  "name": "TimeoutError.js.html",
  "lang": "javascript",
  "title": "TimeoutError",
  "toc": [
    {
      "level": 1,
      "slug": "timeouterror",
      "title": "TimeoutError"
    }
  ]
},
{
  "path": "lib/timed.js.html",
  "originalName": "timed.js",
  "originalPath": "lib/timed.js",
  "name": "timed.js.html",
  "lang": "javascript",
  "title": "timed",
  "toc": [
    {
      "level": 1,
      "slug": "timed",
      "title": "timed"
    },
    {
      "level": 2,
      "slug": "delay-milliseconds-x-",
      "title": "delay(milliseconds, x)"
    },
    {
      "level": 2,
      "slug": "timeout-milliseconds-x-",
      "title": "timeout(milliseconds, x)"
    }
  ]
},
{
  "path": "lib/concurrent.js.html",
  "originalName": "concurrent.js",
  "originalPath": "lib/concurrent.js",
  "name": "concurrent.js.html",
  "lang": "javascript",
  "title": "concurrent",
  "toc": [
    {
      "level": 1,
      "slug": "concurrent",
      "title": "concurrent"
    },
    {
      "level": 2,
      "slug": "sequence-arrayoftasks-args-",
      "title": "sequence(arrayOfTasks, ...args)"
    },
    {
      "level": 2,
      "slug": "pipeline-arrayoftasks-firstargs-",
      "title": "pipeline(arrayOfTasks, ...firstArgs)"
    },
    {
      "level": 2,
      "slug": "parallel-arrayoftasks-args-",
      "title": "parallel(arrayOfTasks, ...args)"
    }
  ]
},
{
  "path": "lib/fn.js.html",
  "originalName": "fn.js",
  "originalPath": "lib/fn.js",
  "name": "fn.js.html",
  "lang": "javascript",
  "title": "fn",
  "toc": [
    {
      "level": 1,
      "slug": "fn",
      "title": "fn"
    },
    {
      "level": 2,
      "slug": "call-normalfunction-args-",
      "title": "call(normalFunction, ...args)"
    },
    {
      "level": 2,
      "slug": "apply-normalfunction-args-",
      "title": "apply(normalFunction, args)"
    },
    {
      "level": 2,
      "slug": "lift-normalfunction-args-",
      "title": "lift(normalFunction, ...args)"
    },
    {
      "level": 2,
      "slug": "compose-funcs-",
      "title": "compose(...funcs)"
    }
  ]
}
];

==> legendary-0.15.1.tgz: package/doc/toc.js <==
window.files = [
{
  "path": "index.html",
  "originalName": "README.md",
  "originalPath": "README.md",
  "name": "index.html",
  "title": "Legendary",
  "toc": [
    {
      "level": 1,
      "slug": "legendary",
      "title": "Legendary"
    },
    {
      "level": 2,
      "slug": "installation",
      "title": "Installation"
    },
    {
      "level": 2,
      "slug": "usage",
      "title": "Usage"
    },
    {
      "level": 2,
      "slug": "theme-song",
      "title": "Theme song"
    }
  ]
},
{
  "path": "lib/main.js.html",
  "originalName": "main.js",
  "originalPath": "lib/main.js",
  "name": "main.js.html",
  "lang": "javascript",
  "title": "main",
  "toc": [
    {
      "level": 1,
      "slug": "main",
      "title": "main"
    },
    {
      "level": 2,
      "slug": "promise",
      "title": "Promise"
    },
    {
      "level": 2,
      "slug": "series",
      "title": "Series"
    },
    {
      "level": 2,
      "slug": "cancellationerror",
      "title": "CancellationError"
    },
    {
      "level": 2,
      "slug": "timeouterror",
      "title": "TimeoutError"
    },
    {
      "level": 2,
      "slug": "timed",
      "title": "timed"
    },
    {
      "level": 2,
      "slug": "concurrent",
      "title": "concurrent"
    },
    {
      "level": 2,
      "slug": "fn",
      "title": "fn"
    },
    {
      "level": 2,
      "slug": "unhandledrejection-reason-",
      "title": "unhandledRejection(reason)"
    }
  ]
},
{
  "path": "lib/promise.js.html",
  "originalName": "promise.js",
  "originalPath": "lib/promise.js",
  "name": "promise.js.html",
  "lang": "javascript",
  "title": "Promise",
  "toc": [
    {
      "level": 1,
      "slug": "promise",
      "title": "Promise"
    },
    {
      "level": 2,
      "slug": "promise-isinstance-x-",
      "title": "Promise.isInstance(x)"
    },
    {
      "level": 2,
      "slug": "promise-from-value-",
      "title": "Promise.from(value)"
    },
    {
      "level": 2,
      "slug": "promise-rejected-reason-",
      "title": "Promise.rejected(reason)"
    },
    {
      "level": 2,
      "slug": "promise-races",
      "title": "Promise Races"
    },
    {
      "level": 3,
      "slug": "promise-all-input-",
      "title": "Promise.all(input)"
    },
    {
      "level": 3,
      "slug": "promise-any-input-",
      "title": "Promise.any(input)"
    },
    {
      "level": 3,
      "slug": "promise-some-input-winsrequired-",
      "title": "Promise.some(input, winsRequired)"
    },
    {
      "level": 3,
      "slug": "promise-join-input-",
      "title": "Promise.join(...input)"
    },
    {
      "level": 2,
      "slug": "promise-then-onfulfilled-onrejected-",
      "title": "Promise#then(onFulfilled, onRejected)"
    },
    {
      "level": 2,
      "slug": "promise-inspectstate-",
      "title": "Promise#inspectState()"
    },
    {
      "level": 2,
      "slug": "promise-cancel-",
      "title": "Promise#cancel()"
    },
    {
      "level": 2,
      "slug": "promise-fork-",
      "title": "Promise#fork()"
    },
    {
      "level": 2,
      "slug": "promise-uncancellable-",
      "title": "Promise#uncancellable()"
    },
    {
      "level": 2,
      "slug": "promise-to-constructor-",
      "title": "Promise#to(constructor)"
    },
    {
      "level": 2,
      "slug": "promise-trace-label-meta-",
      "title": "Promise#trace(label, meta)"
    },
    {
      "level": 2,
      "slug": "promise-tracefulfilled-label-meta-",
      "title": "Promise#traceFulfilled(label, meta)"
    },
    {
      "level": 2,
      "slug": "promise-tracerejected-label-meta-",
      "title": "Promise#traceRejected(label, meta)"
    },
    {
      "level": 2,
      "slug": "promise-yield-value-",
      "title": "Promise#yield(value)"
    },
    {
      "level": 2,
      "slug": "promise-yieldreason-reason-",
      "title": "Promise#yieldReason(reason)"
    },
    {
      "level": 2,
      "slug": "promise-otherwise-onrejected-",
      "title": "Promise#otherwise(onRejected)"
    },
    {
      "level": 2,
      "slug": "promise-ensure-onfulfilledorrejected-",
      "title": "Promise#ensure(onFulfilledOrRejected)"
    },
    {
      "level": 2,
      "slug": "promise-tap-onfulfilledsideeffect-onrejectedsideeffect-",
      "title": "Promise#tap(onFulfilledSideEffect, onRejectedSideEffect)"
    },
    {
      "level": 2,
      "slug": "promise-spread-variadiconfulfilled-",
      "title": "Promise#spread(variadicOnFulfilled)"
    },
    {
      "level": 2,
      "slug": "promise-nodeify-callback-",
      "title": "Promise#nodeify(callback)"
    },
    {
      "level": 2,
      "slug": "promise-cancelafter-milliseconds-",
      "title": "Promise#cancelAfter(milliseconds)"
    },
    {
      "level": 2,
      "slug": "promise-alsocancels-other-",
      "title": "Promise#alsoCancels(other)"
    },
    {
      "level": 2,
      "slug": "promise-send-methodname-args-",
      "title": "Promise#send(methodName, ...args)"
    },
    {
      "level": 2,
      "slug": "promise-prop-name-",
      "title": "Promise#prop(name)"
    }
  ]
},
{
  "path": "lib/series.js.html",
  "originalName": "series.js",
  "originalPath": "lib/series.js",
  "name": "series.js.html",
  "lang": "javascript",
  "title": "Series",
  "toc": [
    {
      "level": 1,
      "slug": "series",
      "title": "Series"
    },
    {
      "level": 2,
      "slug": "series-map-iterator-",
      "title": "Series#map(iterator)"
    },
    {
      "level": 2,
      "slug": "series-mapparallel-maxconcurrent-iterator-",
      "title": "Series#mapParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-each-iterator-",
      "title": "Series#each(iterator)"
    },
    {
      "level": 2,
      "slug": "series-eachparallel-maxconcurrent-iterator-",
      "title": "Series#eachParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-filter-iterator-",
      "title": "Series#filter(iterator)"
    },
    {
      "level": 2,
      "slug": "series-filterparallel-maxconcurrent-iterator-",
      "title": "Series#filterParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-filterout-iterator-",
      "title": "Series#filterOut(iterator)"
    },
    {
      "level": 2,
      "slug": "series-filteroutparallel-maxconcurrent-iterator-",
      "title": "Series#filterOutParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-concat-iterator-",
      "title": "Series#concat(iterator)"
    },
    {
      "level": 2,
      "slug": "series-concatparallel-maxconcurrent-iterator-",
      "title": "Series#concatParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-foldl-initialvalue-iterator-",
      "title": "Series#foldl(initialValue, iterator)"
    },
    {
      "level": 2,
      "slug": "series-foldr-initialvalue-iterator-",
      "title": "Series#foldr(initialValue, iterator)"
    },
    {
      "level": 2,
      "slug": "series-detect-iterator-",
      "title": "Series#detect(iterator)"
    },
    {
      "level": 2,
      "slug": "series-detectparallel-maxconcurrent-iterator-",
      "title": "Series#detectParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-some-iterator-",
      "title": "Series#some(iterator)"
    },
    {
      "level": 2,
      "slug": "series-someparallel-maxconcurrent-iterator-",
      "title": "Series#someParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-every-iterator-",
      "title": "Series#every(iterator)"
    },
    {
      "level": 2,
      "slug": "series-everyparallel-maxconcurrent-iterator-",
      "title": "Series#everyParallel(maxConcurrent, iterator)"
    },
    {
      "level": 2,
      "slug": "series-sortby-iterator-",
      "title": "Series#sortBy(iterator)"
    },
    {
      "level": 2,
      "slug": "series-sortbyparallel-maxconcurrent-iterator-",
      "title": "Series#sortByParallel(maxConcurrent, iterator)"
    }
  ]
},
{
  "path": "lib/CancellationError.js.html",
  "originalName": "CancellationError.js",
  "originalPath": "lib/CancellationError.js",
  "name": "CancellationError.js.html",
  "lang": "javascript",
  "title": "CancellationError",
  "toc": [
    {
      "level": 1,
      "slug": "cancellationerror",
      "title": "CancellationError"
    }
  ]
},
{
  "path": "lib/TimeoutError.js.html",
  "originalName": "TimeoutError.js",
  "originalPath": "lib/TimeoutError.js",
  "name": "TimeoutError.js.html",
  "lang": "javascript",
  "title": "TimeoutError",
  "toc": [
    {
      "level": 1,
      "slug": "timeouterror",
      "title": "TimeoutError"
    }
  ]
},
{
  "path": "lib/timed.js.html",
  "originalName": "timed.js",
  "originalPath": "lib/timed.js",
  "name": "timed.js.html",
  "lang": "javascript",
  "title": "timed",
  "toc": [
    {
      "level": 1,
      "slug": "timed",
      "title": "timed"
    },
    {
      "level": 2,
      "slug": "delay-milliseconds-x-",
      "title": "delay(milliseconds, x)"
    },
    {
      "level": 2,
      "slug": "timeout-milliseconds-x-",
      "title": "timeout(milliseconds, x)"
    }
  ]
},
{
  "path": "lib/concurrent.js.html",
  "originalName": "concurrent.js",
  "originalPath": "lib/concurrent.js",
  "name": "concurrent.js.html",
  "lang": "javascript",
  "title": "concurrent",
  "toc": [
    {
      "level": 1,
      "slug": "concurrent",
      "title": "concurrent"
    },
    {
      "level": 2,
      "slug": "sequence-arrayoftasks-args-",
      "title": "sequence(arrayOfTasks, ...args)"
    },
    {
      "level": 2,
      "slug": "pipeline-arrayoftasks-firstargs-",
      "title": "pipeline(arrayOfTasks, ...firstArgs)"
    },
    {
      "level": 2,
      "slug": "parallel-arrayoftasks-args-",
      "title": "parallel(arrayOfTasks, ...args)"
    }
  ]
},
{
  "path": "lib/fn.js.html",
  "originalName": "fn.js",
  "originalPath": "lib/fn.js",
  "name": "fn.js.html",
  "lang": "javascript",
  "title": "fn",
  "toc": [
    {
      "level": 1,
      "slug": "fn",
      "title": "fn"
    },
    {
      "level": 2,
      "slug": "call-normalfunction-args-",
      "title": "call(normalFunction, ...args)"
    },
    {
      "level": 2,
      "slug": "apply-normalfunction-args-",
      "title": "apply(normalFunction, args)"
    },
    {
      "level": 2,
      "slug": "lift-normalfunction-args-",
      "title": "lift(normalFunction, ...args)"
    },
    {
      "level": 2,
      "slug": "compose-funcs-",
      "title": "compose(...funcs)"
    }
  ]
}
];
